@@ -12,7 +12,6 @@ import time
 from pathlib import Path
 import importlib.resources
 from rich import print as rprint
-from rich.console import Console
 from rich.live import Live
 from rich.spinner import Spinner
 
@@ -175,72 +174,6 @@ def fetch_example(args):
         traceback.print_exc(file=sys.stderr)
         sys.exit(1)
 
-def train_example(args):
-    # sourcery skip: extract-duplicate-method, extract-method, remove-redundant-fstring, split-or-ifs
-    """Train an existing example workflow."""
-    # Create a spinner for the initial check
-    spinner = Spinner("dots", text="[bold green]Preparing to train example...[/bold green]")
-
-    with Live(spinner, refresh_per_second=10):
-        # Check if example exists in the local examples directory
-        local_examples_dir = Path("./examples")
-        workflow_path = local_examples_dir / args.name
-
-        if workflow_path.is_dir():
-            # Get the appropriate env files for this example workflow
-            env_file_path, passwords_file_path = find_default_env_files(local_examples_dir)
-
-            # Check if the files exist
-            env_file = Path(env_file_path)
-            passwords_file = Path(passwords_file_path)
-
-            # Create args object for train_main
-            train_args = argparse.Namespace(
-                workflow_folderpath=str(workflow_path),
-                env_file_path=str(env_file),
-                passwords_file_path=str(passwords_file)
-            )
-
-    # After the spinner, handle any errors or proceed with training
-    if not workflow_path.is_dir():
-        rprint(f"[bold red]Error:[/bold red] Example '{args.name}' not found in '{local_examples_dir}'.")
-        rprint(f"Use 'fastworkflow examples fetch {args.name}' to fetch the example first.")
-        rprint("Or use 'fastworkflow examples list' to see available examples.")
-        sys.exit(1)
-
-    if not env_file.exists() or not passwords_file.exists():
-        rprint(f"[bold red]Error:[/bold red] Required environment files not found:")
-        if not env_file.exists():
-            rprint(f"  - {env_file} (not found)")
-        if not passwords_file.exists():
-            rprint(f"  - {passwords_file} (not found)")
-        rprint("\nPlease run the following command to fetch the example and its environment files:")
-        rprint(f"  fastworkflow examples fetch {args.name}")
-        rprint("\nAfter fetching, edit the passwords file to add your API keys:")
-        rprint(f"  {local_examples_dir}/fastworkflow.passwords.env")
-        sys.exit(1)
-
-    rprint(f"[bold green]Training example[/bold green] '{args.name}' in '{workflow_path}'...")
-
-    try:
-        # Lazy import train_main only when actually training
-        from .train.__main__ import train_main as _train_main
-        # Call train_main directly instead of using subprocess
-        result = _train_main(train_args)
-
-        if result is None or result == 0:
-            rprint(f"\n✅ Successfully trained example '{args.name}'.")
-            rprint(f"You can now run it with:\nfastworkflow examples run {args.name}")
-        else:
-            rprint(f"\n❌ Training failed.")
-            sys.exit(1)
-
-    except Exception as e:
-        rprint(f"[bold red]An unexpected error occurred during training:[/bold red] {e}")
-        import traceback
-        traceback.print_exc(file=sys.stderr)
-        sys.exit(1)
-
 def find_default_env_files(workflow_path):
     """Find the appropriate default env files based on context.
     
@@ -338,14 +271,34 @@ def add_run_parser(subparsers):
     parser_run.add_argument("--startup_action", help="Optional startup action", default="")
     parser_run.add_argument("--keep_alive", help="Optional keep_alive", default=True)
     parser_run.add_argument("--project_folderpath", help="Optional path to project folder containing application code", default=None)
-    parser_run.add_argument(
-        "--run_as_agent",
-        help="Run in agent mode (uses DSPy for tool selection)",
-        action="store_true",
-        default=False,
-    )
     parser_run.set_defaults(func=lambda args: run_with_defaults(args))
 
+def add_run_fastapi_mcp_parser(subparsers):
+    """Add subparser for the 'run_fastapi_mcp' command."""
+    parser_run_fastapi_mcp = subparsers.add_parser("run_fastapi_mcp", help="Run a workflow as a FastAPI server with MCP support.")
+    parser_run_fastapi_mcp.add_argument("workflow_path", help="Path to the workflow folder")
+    
+    # Default env files will be determined at runtime based on the workflow path
+    parser_run_fastapi_mcp.add_argument(
+        "env_file_path",
+        nargs='?',
+        default=None,
+        help="Path to the environment file (default: .env in current directory, or bundled env file for examples)",
+    )
+    parser_run_fastapi_mcp.add_argument(
+        "passwords_file_path",
+        nargs='?',
+        default=None,
+        help="Path to the passwords file (default: passwords.env in current directory, or bundled env file for examples)",
+    )
+    parser_run_fastapi_mcp.add_argument("--context", help="Optional context (JSON string)", default=None)
+    parser_run_fastapi_mcp.add_argument("--startup_command", help="Optional startup command", default=None)
+    parser_run_fastapi_mcp.add_argument("--startup_action", help="Optional startup action (JSON string)", default=None)
+    parser_run_fastapi_mcp.add_argument("--project_folderpath", help="Optional path to project folder containing application code", default=None)
+    parser_run_fastapi_mcp.add_argument("--port", type=int, default=8000, help="Port to run the FastAPI server on (default: 8000)")
+    parser_run_fastapi_mcp.add_argument("--host", default="0.0.0.0", help="Host to bind the FastAPI server to (default: 0.0.0.0)")
+    parser_run_fastapi_mcp.set_defaults(func=lambda args: run_fastapi_mcp_with_defaults(args))
+
 def train_with_defaults(args):  # sourcery skip: extract-duplicate-method
     """Wrapper for train_main that sets default env file paths based on context."""
     if args.env_file_path is None or args.passwords_file_path is None:
@@ -363,7 +316,7 @@ def train_with_defaults(args):  # sourcery skip: extract-duplicate-method
             example_name = os.path.basename(args.workflow_folderpath)
             print("\nThis appears to be an example workflow. Please run:")
             print(f"  fastworkflow examples fetch {example_name}")
-            print(f"  fastworkflow examples train {example_name}")
+            print(f"  fastworkflow train ./examples/{example_name} ./examples/fastworkflow.env ./examples/fastworkflow.passwords.env")
         else:
             print("\nPlease ensure this file exists with required environment variables.")
             print("You can create a basic .env file in your current directory.")
@@ -376,7 +329,7 @@ def train_with_defaults(args):  # sourcery skip: extract-duplicate-method
             example_name = os.path.basename(args.workflow_folderpath)
             print("\nThis appears to be an example workflow. Please run:")
             print(f"  fastworkflow examples fetch {example_name}")
-            print(f"  fastworkflow examples train {example_name}")
+            print(f"  fastworkflow train ./examples/{example_name} ./examples/fastworkflow.env ./examples/fastworkflow.passwords.env")
         else:
             print("\nPlease ensure this file exists with required API keys.")
             print("You can create a basic passwords.env file in your current directory.")
@@ -403,7 +356,7 @@ def run_with_defaults(args):  # sourcery skip: extract-duplicate-method
             example_name = os.path.basename(args.workflow_path)
             print("\nThis appears to be an example workflow. Please run:")
             print(f"  fastworkflow examples fetch {example_name}")
-            print(f"  fastworkflow examples train {example_name}")
+            print(f"  fastworkflow train ./examples/{example_name} ./examples/fastworkflow.env ./examples/fastworkflow.passwords.env")
         else:
             print("\nPlease ensure this file exists with required environment variables.")
             print("You can create a basic .env file in your current directory.")
@@ -416,7 +369,7 @@ def run_with_defaults(args):  # sourcery skip: extract-duplicate-method
             example_name = os.path.basename(args.workflow_path)
             print("\nThis appears to be an example workflow. Please run:")
             print(f"  fastworkflow examples fetch {example_name}")
-            print(f"  fastworkflow examples train {example_name}")
+            print(f"  fastworkflow train ./examples/{example_name} ./examples/fastworkflow.env ./examples/fastworkflow.passwords.env")
         else:
             print("\nPlease ensure this file exists with required API keys.")
             print("You can create a basic passwords.env file in your current directory.")
@@ -426,85 +379,62 @@ def run_with_defaults(args):  # sourcery skip: extract-duplicate-method
     from .run.__main__ import run_main as _run_main
     return _run_main(args)
 
-def run_example(args):
-    # sourcery skip: extract-duplicate-method, extract-method, remove-redundant-fstring, split-or-ifs
-    """Run an existing example workflow."""
-    # Create a spinner for the initial check
-    spinner = Spinner("dots", text="[bold green]Preparing to run example...[/bold green]")
+def run_fastapi_mcp_with_defaults(args):  # sourcery skip: extract-duplicate-method
+    """Wrapper for fastapi mcp server that sets default env file paths based on context."""
+    if args.env_file_path is None or args.passwords_file_path is None:
+        default_env, default_passwords = find_default_env_files(args.workflow_path)
+    if args.env_file_path is None:
+        args.env_file_path = default_env
+    if args.passwords_file_path is None:
+        args.passwords_file_path = default_passwords
 
-    with Live(spinner, refresh_per_second=10):
-        # Check if example exists in the local examples directory
-        local_examples_dir = Path("./examples")
-        workflow_path = local_examples_dir / args.name
-
-        if workflow_path.is_dir():
-            # Get the appropriate env files for this example workflow
-            env_file_path, passwords_file_path = find_default_env_files(local_examples_dir)
-
-            # Check if the files exist
-            env_file = Path(env_file_path)
-            passwords_file = Path(passwords_file_path)
-
-            # Check if the example has been trained
-            command_info_dir = workflow_path / "___command_info"
-
-    # After the spinner, handle any errors or proceed with running
-    if not workflow_path.is_dir():
-        rprint(f"[bold red]Error:[/bold red] Example '{args.name}' not found in '{local_examples_dir}'.")
-        rprint(f"Use 'fastworkflow examples fetch {args.name}' to fetch the example first.")
-        rprint("Or use 'fastworkflow examples list' to see available examples.")
+    # Check if the files exist and provide helpful error messages
+    if not os.path.exists(args.env_file_path):
+        print(f"Error: Environment file not found at: {args.env_file_path}", file=sys.stderr)
+        # Check if this is an example workflow
+        if "/examples/" in str(args.workflow_path) or "\\examples\\" in str(args.workflow_path):
+            example_name = os.path.basename(args.workflow_path)
+            print("\nThis appears to be an example workflow. Please run:")
+            print(f"  fastworkflow examples fetch {example_name}")
+            print(f"  fastworkflow run_fastapi_mcp ./examples/{example_name} ./examples/fastworkflow.env ./examples/fastworkflow.passwords.env")
+        else:
+            print("\nPlease ensure this file exists with required environment variables.")
+            print("You can create a basic .env file in your current directory.")
         sys.exit(1)
 
-    if not env_file.exists() or not passwords_file.exists():
-        rprint(f"[bold red]Error:[/bold red] Required environment files not found:")
-        if not env_file.exists():
-            rprint(f"  - {env_file} (not found)")
-        if not passwords_file.exists():
-            rprint(f"  - {passwords_file} (not found)")
-        rprint("\nPlease run the following command to fetch the example and its environment files:")
-        rprint(f"  fastworkflow examples fetch {args.name}")
-        rprint("\nAfter fetching, edit the passwords file to add your API keys:")
-        rprint(f"  {local_examples_dir}/fastworkflow.passwords.env")
-        rprint("\nThen train the example before running it:")
-        rprint(f"  fastworkflow examples train {args.name}")
+    if not os.path.exists(args.passwords_file_path):
+        print(f"Error: Passwords file not found at: {args.passwords_file_path}", file=sys.stderr)
+        # Check if this is an example workflow
+        if "/examples/" in str(args.workflow_path) or "\\examples\\" in str(args.workflow_path):
+            example_name = os.path.basename(args.workflow_path)
+            print("\nThis appears to be an example workflow. Please run:")
+            print(f"  fastworkflow examples fetch {example_name}")
+            print(f"  fastworkflow run_fastapi_mcp ./examples/{example_name} ./examples/fastworkflow.env ./examples/fastworkflow.passwords.env")
+        else:
+            print("\nPlease ensure this file exists with required API keys.")
+            print("You can create a basic passwords.env file in your current directory.")
         sys.exit(1)
 
-    # Check if the example has been trained
-    if not command_info_dir.exists() or not any(command_info_dir.iterdir()):
-        rprint(f"[bold yellow]Warning:[/bold yellow] Example '{args.name}' does not appear to be trained yet.")
-        rprint(f"Please train the example first with:")
-        rprint(f"  fastworkflow examples train {args.name}")
-        response = input("Do you want to continue anyway? [y/N] ")
-        if response.lower() != 'y':
-            rprint("Operation cancelled.")
-            sys.exit(0)
-
-    rprint(f"[bold green]Running example[/bold green] '{args.name}'...")
-
-    # For interactive applications, we need to use os.execvp to replace the current process
-    # This ensures that stdin/stdout/stderr are properly connected for interactive use
+    # Use subprocess to run python -m fastworkflow.run_fastapi_mcp with the correct arguments
     cmd = [
-        sys.executable,
-        "-m", "fastworkflow.run",
-        str(workflow_path),
-        str(env_file),
-        str(passwords_file)
+        sys.executable, '-m', 'fastworkflow.run_fastapi_mcp',
+        '--workflow_path', args.workflow_path,
+        '--env_file_path', args.env_file_path,
+        '--passwords_file_path', args.passwords_file_path,
+        '--port', str(args.port),
+        '--host', args.host,
     ]
-
-    # Forward agent mode flag if requested
-    if getattr(args, "run_as_agent", False):
-        cmd.append("--run_as_agent")
-
-    try:
-        rprint(f"[bold green]Starting interactive session...[/bold green]")
-        # Replace the current process with the run command
-        # This ensures that the interactive prompt works correctly
-        os.execvp(sys.executable, cmd)
-    except Exception as e:
-        rprint(f"[bold red]An unexpected error occurred while running the example:[/bold red] {e}")
-        import traceback
-        traceback.print_exc(file=sys.stderr)
-        sys.exit(1)
+    if args.context:
+        cmd.extend(['--context', args.context])
+    if args.startup_command:
+        cmd.extend(['--startup_command', args.startup_command])
+    if args.startup_action:
+        cmd.extend(['--startup_action', args.startup_action])
+    if args.project_folderpath:
+        cmd.extend(['--project_folderpath', args.project_folderpath])
+    
+    # Run the subprocess
+    return subprocess.run(cmd).returncode
 
 def main():
     """Main function for the fastworkflow CLI."""
@@ -528,27 +458,12 @@ def main():
     parser_fetch.add_argument("--force", action="store_true", help="Force overwrite if example already exists")
     parser_fetch.set_defaults(func=fetch_example)
     
-    # 'examples train' command
-    parser_train_example = examples_subparsers.add_parser("train", help="Train a specific example")
-    parser_train_example.add_argument("name", help="The name of the example to train")
-    parser_train_example.set_defaults(func=train_example)
-    
-    # 'examples run' command
-    parser_run_example = examples_subparsers.add_parser("run", help="Run a specific example")
-    parser_run_example.add_argument("name", help="The name of the example to run")
-    parser_run_example.add_argument(
-        "--run_as_agent",
-        help="Run the example in agent mode (uses DSPy for tool selection)",
-        action="store_true",
-        default=False,
-    )
-    parser_run_example.set_defaults(func=run_example)
-    
     # Add top-level commands
     add_build_parser(subparsers)
     add_refine_parser(subparsers)
     add_train_parser(subparsers)
     add_run_parser(subparsers)
+    add_run_fastapi_mcp_parser(subparsers)
 
     try:
         args = parser.parse_args()
